import { Cell } from 'vant'
import { defineComponent, PropType } from 'vue'
import styles from './index.module.less'

// import QrCodeVue from 'qrcode.vue'
// import { toPng } from 'html-to-image'

import iconTeacher from '@/common/images/icon_teacher.png'
import { state } from '@/state'
import CodeDownload from './code-down-load'

export const getAssetsHomeFile = (fileName: string) => {
  const path = `./images/${fileName}`
  const modules = import.meta.globEager('./images/*')
  return modules[path].default
}

export default defineComponent({
  name: 'share-item',
  props: {
    teacherId: {
      type: Number
    },
    shareUrl: {
      type: String,
      default: ''
    },
    showType: {
      // 显示背景图
      type: String as PropType<'yellow' | 'pink' | 'defult'>,
      default: 'default'
    },
    shareType: {
      // 分享类型
      type: String as PropType<'' | 'video' | 'music' | 'live' | 'mall'>,
      default: ''
    }
  },
  data() {
    return {
      heardUrl: null as any
    }
  },
  computed: {
    getString() {
      const tempalte = {
        live: [
          {
            title: '精品必修课程来啦~~~',
            content: '优秀的老师能帮助您快速成长',
            tips: '多种技巧干货分享'
          },
          {
            title: '零基础学习，让你轻松上手就能演奏',
            content: '听说快乐和可爱都会传染，让课程变得更轻松',
            tips: '强烈推荐'
          },
          {
            title: '优秀是一种习惯，越早养成越好',
            content: '快来提升自己，让自己更优秀',
            tips: '这套课程不错哟！推荐给你~'
          }
        ],
        music: [
          {
            title: '科学练习，有助于水平快速提升',
            content: '随时陪伴，让你的练习更加轻松',
            tips: '这首曲子很不错！推荐给你~'
          },
          {
            title: '没有天赋异禀，优秀的人总是努力翻山越岭',
            content: '只有反复练习才能在台上游刃有余',
            tips: '这首曲子不错哟，推荐给你~'
          },
          {
            title: '海量乐谱，欢迎大家来围观',
            content: '每一首作品，都有一颗精心策划的心',
            tips: '这首曲子不错哟，推荐给你~'
          }
        ],
        mall: [
          {
            title: '开业大吉，火力全开',
            content: '做最稳定的品质，给最优惠的价格',
            tips: '好物推荐，优惠多多'
          },
          {
            title: '新品嗨购，优惠不停',
            content: '有品质才会热爱，有诚信才会信赖',
            tips: '好物推荐，优惠多多'
          },
          {
            title: '精选优惠产品来啦~',
            content: '快来选购一件适合你的乐器吧~',
            tips: '好物推荐，优惠多多'
          }
        ]
      }
      let selectItem: any = []
      if (this.shareType === 'music') {
        selectItem = tempalte.music
      } else if (this.shareType === 'mall') {
        selectItem = tempalte.mall
      } else {
        selectItem = tempalte.live
      }

      if (this.showType === 'yellow') {
        return selectItem[1]
      } else if (this.showType === 'pink') {
        return selectItem[2]
      } else {
        return selectItem[0]
      }
    }
  },
  mounted() {
    // alert(state.user.data.headUrl)
    // this.heardUrl =
    //   state.user.data.headUrl +
    //   '@base@tag=imgscale&m=0&w=100&et=1&eth=100&etw=100&etc=ccc'
    // this.heardUrl = state.user.data.heardUrl + '@base@tag=imgScale&p=25'
    this.heardUrl =
      state.user.data.heardUrl + '@base@tag=imgScale&h=80&w=80&m=1'
    // '@base@tag=imgscale&m=0&w=80&et=1&eth=100&etw=100&etc=cccccc'
    // ?time= +
    // new Date().valueOf()
    console.log(this.heardUrl, 'heardUrl')
  },
  render() {
    return (
      <div
        class={[
          styles.shareSection,
          styles.shareContainer,
          styles[this.showType]
        ]}
        id="share-preview-container"
      >
        <div class={styles.shareTitle}>
          <p class={styles.title} v-html={this.getString?.title}></p>
          <p class={styles.titleTip}>{this.getString?.content}</p>
        </div>

        {this.$slots.default && this.$slots.default()}

        <Cell
          center
          border={false}
          class={styles.shareTeacher}
          v-slots={{
            icon: () => (
              <div class={styles.teacherImg}>
                <img
                  src={state.user.data.heardUrl ? this.heardUrl : iconTeacher}
                  class={styles.img}
                  style={{ objectFit: 'cover' }}
                  crossorigin="anonymous"
                />
                {/* <div
                  class={styles.img}
                  style={{
                    background: `url(${
                      state.user.data.heardUrl ? this.heardUrl : iconTeacher
                    }) no-repeat center`,
                    backgroundSize: 'cover'
                  }}
                ></div> */}
                <img
                  class={styles.recommend}
                  src={getAssetsHomeFile('recommend.png')}
                />
              </div>
            ),
            title: () => (
              <div>
                <p class={styles.name}>{this.getString?.tips}</p>
                <p class={styles.titleTips}>
                  <span>{state.user.data.username}</span>
                  酷乐秀入驻老师
                </p>
              </div>
            )
          }}
        />

        <CodeDownload shareUrl={this.shareUrl} />
      </div>
    )
  }
})
